-------------------------------------------------------------------------------
--|> Loader
-- Loads and checks the database
-------------------------------------------------------------------------------
--|> UPVALUE GLOBALS
-------------------------------------------------------------------------------
local weizPVP = weizPVP
local wipe = wipe
local UnitLevel = UnitLevel
local GetRealmName = GetRealmName
local GetUnitName = GetUnitName
local MAX_PLAYER_LEVEL_TABLE = MAX_PLAYER_LEVEL_TABLE
local GetExpansionLevel = GetExpansionLevel
local UnitFactionGroup = UnitFactionGroup
local select = select
local UIParent = UIParent
-------------------------------------------------------------------------------
--> Load DB
-------------------------------------------------------------------------------
function weizPVP:LoadDB()
    --> Check for Player DB
    if weizPVP.db.global.PlayerDB then
        weizPVP.PlayerDB = weizPVP.db.global.PlayerDB
    else
        weizPVP.db.global.PlayerDB = {}
        weizPVP.PlayerDB = {}
    end

    local DBMatch
    if weizPVP.db.profile.Options.DB_VERSION and weizPVP.Options.DB_VERSION then
        DBMatch = weizPVP.db.profile.Options.DB_VERSION == weizPVP.Options.DB_VERSION
    end

    --> Check for Options
    if weizPVP.db.profile.Options and DBMatch == true then
        weizPVP.Options = weizPVP.db.profile.Options
    else
        --> LOAD DEFAULT OPTIONS
        --> mismatch warning
        if DBMatch == false then
            weizPVP:PrintAddonMessage(
                "|cffff3838WARNING:|r The database has been updated to 2.0; previous settings have been wiped"
            )
        end

        --> REMOVAL OF OLDER SETTINGS DB
        if weizPVP.db.profile.Settings then
            wipe(weizPVP.db.profile.Settings)
        end
        if weizPVP.db.profile.weizPVP_DB then
            wipe(weizPVP.db.profile.weizPVP_DB)
        end

        --> Init options
        wipe(weizPVP.db.profile.Options)
        weizPVP.db.profile.Options = {}
        weizPVP.SetDefaultOptionsTable()
        weizPVP.db.profile.Options = weizPVP.Options
    end

    --> Add in new options if they don't exist in saved variables
    if not weizPVP.Options.EnabledInBattlegrounds then
        weizPVP.Options.EnabledInBattlegrounds = false
    end
    if not weizPVP.Options.AudioAlerts then
        weizPVP.Options.AudioAlerts = {}
        weizPVP.Options.AudioAlerts.DetectedPlayerSound = false
    end
    if not weizPVP.Options.Crosshair then
        weizPVP.Options.Crosshair = {}
        weizPVP.Options.Crosshair.Enabled = true
    end
    if not weizPVP.Options.Crosshair.NameEnabled then
        weizPVP.Options.Crosshair.NameEnabled = false
    end
    if not weizPVP.Options.Crosshair.GuildEnabled then
        weizPVP.Options.Crosshair.GuildEnabled = false
    end
    if not weizPVP.Options.LagMode then
        weizPVP.Options.LagMode = {}
        weizPVP.Options.LagMode.Enabled = false
        weizPVP.Options.LagMode.Active = false
    end
    if not weizPVP.Options.LagMode.FPSThreshold then
        weizPVP.Options.LagMode.FPSThreshold = 30
    end
    if not weizPVP.Options.LagMode.Active then
        weizPVP.Options.LagMode.Active = false
	end


    if not weizPVP.Options.StealthAlert then
        weizPVP.Options.StealthAlert = {}
	end

    if not weizPVP.Options.StealthAlert.Enabled then
        weizPVP.Options.StealthAlert.Enabled = true
	end

    if not weizPVP.Options.StealthAlert.EnableSound then
        weizPVP.Options.StealthAlert.EnableSound = true
	end


    --> Apply current settings
    weizPVP:SaveAddonData()
end

function weizPVP:ApplyStaticOptions()
    -------------------------------------------------------------------------------
    --=> Static Variables
    -------------------------------------------------------------------------------
    --> Sorting
    weizPVP.Options.Sorting = {}
    weizPVP.Options.Sorting.NearbyInactiveTimeout = 32
    weizPVP.Options.Sorting.NearbyActiveTimeout = 20

    -------------------------------------------------------------------------------
    --=> Enviromental Variables
    --> Holds infomation about the player's stats, game settings, system settings, etc.
    -------------------------------------------------------------------------------
    --> Get Player Unit Info
    weizPVP.Player = {}
    weizPVP.Player.Level = UnitLevel("player")
    --> player's level
    weizPVP.Player.CurrentRealm = GetRealmName()
    --> player's realm name
    weizPVP.Player.Name = GetUnitName("player")
    --> player's profile name
    weizPVP.Player.Faction = select(1, UnitFactionGroup("player"))
    --> Horde/Alliance
    weizPVP.MaxPlayerLevel = MAX_PLAYER_LEVEL_TABLE[GetExpansionLevel()]

    --> Get Display Info
    weizPVP.Display = {}
    weizPVP.Display.Width = GetScreenWidth()
    weizPVP.Display.Height = GetScreenHeight()
    weizPVP.Display.xFactor = (768 / weizPVP.Display.Width) * (weizPVP.Display.Width / weizPVP.Display.Height)
    weizPVP.Display.yFactor = 768 / weizPVP.Display.Height
    weizPVP.Display.UIScale = UIParent:GetScale()
    weizPVP.Display.EffectiveScale = UIParent:GetEffectiveScale()
    weizPVP.Display.CVarUiScale = GetCVar("uiScale")
    weizPVP.Display.CurrentFPS = GetFramerate()

    --> Init Static Data Tables
    weizPVP:CreateAbilityLevelDB()
    weizPVP:CreateSpecDB()
    weizPVP:CreateAuraSpecDB()

    --> Create Core Frames and Bars
    weizPVP:CreateCoreFrames()
    weizPVP:CreateBars()
    weizPVP:CreateStatusBar()

    --> Check lock
    if weizPVP.Options.WindowLocked ~= true then
        weizPVP.Options.WindowLocked = false
    end
    weizPVP:ToggleLocked(weizPVP.Options.WindowLocked)

    --> Create Crosshair Frames
    if weizPVP.Options.Crosshair.Enabled then
        weizPVP.EnableCrosshair()
        weizPVP.CrosshairFrame:PLAYER_TARGET_CHANGED()
    end
    --> Create Stealth Alert Frame
    weizPVP:CreateStealthAlertFrame()
    weizPVP.Addon = {}
    weizPVP.Addon.Enabled = true
end
